# MLflow runtime for MLServer

This package provides a MLServer runtime compatible with [MLflow
models](https://www.mlflow.org/docs/latest/models.html).

## Usage

You can install the runtime, alongside `mlserver`, as:

```bash
pip install mlserver mlserver-mlflow
```
